@@ -1,5 +1,6 @@
+import os
 __name__ = "diffgram"
-__version__ = "0.3.4"
+__version__ = os.getenv('DIFFGRAM_SDK_VERSION')
 
 from diffgram.core.core import Project
 from diffgram.file.file import File
