@@ -3,16 +3,12 @@ import warnings
 
 def label_new(self,
               label: dict,
-              schema_id: int = None,
-              allow_duplicates: bool = False,
-              print_success: bool = True):
+              schema_id: int = None):
     """
 
     Arguments
         self,
         label_list, a list of label strings
-        ignore_duplicates, bool
-        print_success, bool
 
     Expects
 
@@ -29,14 +25,6 @@ def label_new(self,
     if not name:
         raise Exception("Please provide a key of name with a value of label")
     label['schema_id'] = schema_id
-    if allow_duplicates is False:
-
-        label_file_id = self.name_to_file_id.get(name, None)
-
-        if label_file_id:
-            warnings.warn("\n\n '" + name + "' label already exists and was skipped." + \
-                          "\n Set allow_duplicates = True to bypass this check. \n")
-            return
 
     endpoint = "/api/v1/project/" + self.project_string_id + \
                "/label/new"
@@ -46,8 +34,8 @@ def label_new(self,
 
     data = response.json()
     self.get_label_file_dict()
+
     if data["log"]["success"] == True:
-        if print_success is True:
-            print("New label success")
+        return data['label']
     else:
         raise Exception(data["log"]["error"])
